==> skill-core-17.0.1-sources.jar: com/ptteng/common/skill/model/Occupation.java <==
package com.ptteng.common.skill.model;

import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import javax.persistence.*;
import java.io.Serializable;


@Entity
@Table(name = "occupation")
public class Occupation implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 4962248169743004672L;
    /**
     *  未发布
     *
     */
    public static final Integer Status_Unpublished = 1;

    /**
     * 发布
     */
    public static final Integer Status_Published = 2;//强制更新
    /**
     * 在常量表中标记职业的Type
     */
	public static final String Constant_Type_occupation = "occupation_type";
    /**
     * js职业name,用于线下学员设置入学和结业时间时的排除选项
     * 线下学员入学时间为加入除js（web学员一般是先加css班级）班级时间，并根据班级所属分院，自动设置结业时间
     */

    public static final String Occupation_name_js = "js";

    public static final Long CSS_ID = 1L;
    public static final Long JS_ID = 2L;


    private Long id;


    private String name;


    private String CnName;

    //职业qq群，新增班级前端默认传职业qq群
    private String qq;

    //职业qqUrl，用于职业任务详情中加入qq群
    private String qqUrl;


    private String brief;


    private String description;


    private Integer threshold;


    private Integer difficult;


    private String cycle;
    
    private String basis;


    private Integer company;

    private String skillImg;


    private String img;


    private Long onlineGradeCount=0L;


    private Long offlineGradeCount=0L;


    private Long classCount=0L;


    private Long onlineClassCount=0L;


    private Long offlineClassCount=0L;


    private Long onlineUserCount=0L;
    private Long outlineUserCount=0L;

    private Long offlineUserCount=0L;


    private Long coreUserCount=0L;
    
    
   
    private Integer people;
    
    /**
     * 职业分组，跟Constant表里的name对应一致
     *
     */
    private String type;
    
    private String salary;
    
    private String modules;

    private Long publishAt;
    
    private Integer status;
    
    private Long createBy;


    private Long updateBy;


    private Long updateAt;


    private Long createAt;
  
    

    
    
    /**
     * 修真院13期新增字段
     * @return
     */
    private String passingRate;
    private String completeTotal;
    private String completeTotalOffline;
    private String completeTotalOutline;
    private String completeTotalOnline;
    private String submitTaskTotal;
    private String submitTaskOffline;
    private String submitTaskOutline;
    private String submitTaskOnline;
    private String receiveTaskTotal;
    private String receiveTaskOffline;
    private String receiveTaskOutline;
    private String receiveTaskOnline;
    private String averageTimeTotal;
    private String averageTimeOffline;
    private String averageTimeOutline;
    private String averageTimeOnline;
    private String dailyQualityTotal;
    private String dailyQualityOffline;
    private String dailyQualityOutline;
    private String dailyQualityOnline;
    
    
    
    
    
    
    
    
    
    
    
    
    
    @Column(name="passing_rate")
    public String getPassingRate() {
		return passingRate;
	}


	public void setPassingRate(String passingRate) {
		this.passingRate = passingRate;
	}

	@Column(name="complete_total")
	public String getCompleteTotal() {
		return completeTotal;
	}


	public void setCompleteTotal(String completeTotal) {
		this.completeTotal = completeTotal;
	}

	@Column(name="complete_total_offline")
	public String getCompleteTotalOffline() {
		return completeTotalOffline;
	}


	public void setCompleteTotalOffline(String completeTotalOffline) {
		this.completeTotalOffline = completeTotalOffline;
	}

	@Column(name="complete_total_outline")
	public String getCompleteTotalOutline() {
		return completeTotalOutline;
	}


	public void setCompleteTotalOutline(String completeTotalOutline) {
		this.completeTotalOutline = completeTotalOutline;
	}

	@Column(name="complete_total_online")
	public String getCompleteTotalOnline() {
		return completeTotalOnline;
	}


	public void setCompleteTotalOnline(String completeTotalOnline) {
		this.completeTotalOnline = completeTotalOnline;
	}

	@Column(name="submit_task_total")
	public String getSubmitTaskTotal() {
		return submitTaskTotal;
	}


	public void setSubmitTaskTotal(String submitTaskTotal) {
		this.submitTaskTotal = submitTaskTotal;
	}

	@Column(name="submit_task_offline")
	public String getSubmitTaskOffline() {
		return submitTaskOffline;
	}


	public void setSubmitTaskOffline(String submitTaskOffline) {
		this.submitTaskOffline = submitTaskOffline;
	}

	@Column(name="submit_task_outline")
	public String getSubmitTaskOutline() {
		return submitTaskOutline;
	}


	public void setSubmitTaskOutline(String submitTaskOutline) {
		this.submitTaskOutline = submitTaskOutline;
	}

	@Column(name="submit_task_online")
	public String getSubmitTaskOnline() {
		return submitTaskOnline;
	}


	public void setSubmitTaskOnline(String submitTaskOnline) {
		this.submitTaskOnline = submitTaskOnline;
	}

	@Column(name="receive_task_total")
	public String getReceiveTaskTotal() {
		return receiveTaskTotal;
	}


	public void setReceiveTaskTotal(String receiveTaskTotal) {
		this.receiveTaskTotal = receiveTaskTotal;
	}

	@Column(name="receive_task_offline")
	public String getReceiveTaskOffline() {
		return receiveTaskOffline;
	}


	public void setReceiveTaskOffline(String receiveTaskOffline) {
		this.receiveTaskOffline = receiveTaskOffline;
	}

	@Column(name="receive_task_outline")
	public String getReceiveTaskOutline() {
		return receiveTaskOutline;
	}


	public void setReceiveTaskOutline(String receiveTaskOutline) {
		this.receiveTaskOutline = receiveTaskOutline;
	}

	@Column(name="receive_task_online")
	public String getReceiveTaskOnline() {
		return receiveTaskOnline;
	}


	public void setReceiveTaskOnline(String receiveTaskOnline) {
		this.receiveTaskOnline = receiveTaskOnline;
	}
  
	@Column(name="average_time_total")
	public String getAverageTimeTotal() {
		return averageTimeTotal;
	}


	public void setAverageTimeTotal(String averageTimeTotal) {
		this.averageTimeTotal = averageTimeTotal;
	}

	@Column(name="average_time_offline")
	public String getAverageTimeOffline() {
		return averageTimeOffline;
	}


	public void setAverageTimeOffline(String averageTimeOffline) {
		this.averageTimeOffline = averageTimeOffline;
	}

	@Column(name="average_time_outline")
	public String getAverageTimeOutline() {
		return averageTimeOutline;
	}


	public void setAverageTimeOutline(String averageTimeOutline) {
		this.averageTimeOutline = averageTimeOutline;
	}

	@Column(name="average_time_online")
	public String getAverageTimeOnline() {
		return averageTimeOnline;
	}


	public void setAverageTimeOnline(String averageTimeOnline) {
		this.averageTimeOnline = averageTimeOnline;
	}

	@Column(name="daily_quality_total")
	public String getDailyQualityTotal() {
		return dailyQualityTotal;
	}

    
	public void setDailyQualityTotal(String dailyQualityTotal) {
		this.dailyQualityTotal = dailyQualityTotal;
	}

	@Column(name="daily_quality_offline")
	public String getDailyQualityOffline() {
		return dailyQualityOffline;
	}


	public void setDailyQualityOffline(String dailyQualityOffline) {
		this.dailyQualityOffline = dailyQualityOffline;
	}

	@Column(name="daily_quality_outline")
	public String getDailyQualityOutline() {
		return dailyQualityOutline;
	}


	public void setDailyQualityOutline(String dailyQualityOutline) {
		this.dailyQualityOutline = dailyQualityOutline;
	}

	@Column(name="daily_quality_online")
	public String getDailyQualityOnline() {
		return dailyQualityOnline;
	}


	public void setDailyQualityOnline(String dailyQualityOnline) {
		this.dailyQualityOnline = dailyQualityOnline;
	}


	@Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "id")
    public Long getId() {
        return id;
    }


    public void setId(Long id) {
        this.id = id;
    }
    @Column(name = "outline_user_count")
    public Long getOutlineUserCount() {
        return outlineUserCount;
    }

    public void setOutlineUserCount(Long outlineUserCount) {
        this.outlineUserCount = outlineUserCount;
    }

    @Column(name = "modules")
    public String getModules() {
        return modules;
    }

    public void setModules(String modules) {
        this.modules = modules;
    }


    @Column(name = "publish_at")
    public Long getPublishAt() {
        return publishAt;
    }

    public void setPublishAt(Long publishAt) {
        this.publishAt = publishAt;
    }
    @Column(name = "status")
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
    @Column(name = "people")
    public Integer getPeople() {
        return people;
    }

    public void setPeople(Integer people) {
        this.people = people;
    }
    @Column(name = "salary")
    public String getSalary() {
        return salary;
    }

    public void setSalary(String salary) {
        this.salary = salary;
    }

    @Column(name = "name")
    public String getName() {
        return name;
    }


    public void setName(String name) {
        this.name = name;
    }

    @Column(name = "cn_name")
    public String getCnName() {
        return CnName;
    }

    public void setCnName(String cnName) {
        CnName = cnName;
    }


    @Column(name = "qq")
    public String getQq() {
        return qq;
    }

    public void setQq(String qq) {
        this.qq = qq;
    }

    @Column(name = "qq_url")
    public String getQqUrl() {
        return qqUrl;
    }

    public void setQqUrl(String qqUrl) {
        this.qqUrl = qqUrl;
    }

    @Column(name = "brief")
    public String getBrief() {
        return brief;
    }

    public void setBrief(String brief) {
        this.brief = brief;
    }
    
    
    
    @Column(name = "basis")
    public String getBasis() {
		return basis;
	}


	public void setBasis(String basis) {
		this.basis = basis;
	}


	@Column(name = "description")
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    @Column(name = "threshold")
    public Integer getThreshold() {
        return threshold;
    }

    public void setThreshold(Integer threshold) {
        this.threshold = threshold;
    }

    @Column(name = "difficult")
    public Integer getDifficult() {
        return difficult;
    }

    public void setDifficult(Integer difficult) {
        this.difficult = difficult;
    }

    @Column(name = "cycle")
    public String getCycle() {
        return cycle;
    }

    public void setCycle(String cycle) {
        this.cycle = cycle;
    }

    @Column(name = "company")
    public Integer getCompany() {
        return company;
    }

    public void setCompany(Integer company) {
        this.company = company;
    }

 
    @Column(name = "skill_img")
    public String getSkillImg() {
        return skillImg;
    }

    public void setSkillImg(String skillImg) {
        this.skillImg = skillImg;
    }


    @Column(name = "img")
    public String getImg() {
        return img;
    }

    public void setImg(String img) {
        this.img = img;
    }
    
    
    
    
    @Column(name = "type")
    public String getType() {
		return type;
	}


	public void setType(String type) {
		this.type = type;
	}


	@Column(name = "online_grade_count")
    public Long getOnlineGradeCount() {
        return onlineGradeCount;
    }

    public void setOnlineGradeCount(Long onlineGradeCount) {
        this.onlineGradeCount = onlineGradeCount;
    }

    @Column(name = "offline_grade_count")
    public Long getOfflineGradeCount() {
        return offlineGradeCount;
    }

    public void setOfflineGradeCount(Long offlineGradeCount) {
        this.offlineGradeCount = offlineGradeCount;
    }

    @Column(name = "online_class_count")
    public Long getOnlineClassCount() {
        return onlineClassCount;
    }

    public void setOnlineClassCount(Long onlineClassCount) {
        this.onlineClassCount = onlineClassCount;
    }

    @Column(name = "offline_class_count")
    public Long getOfflineClassCount() {
        return offlineClassCount;
    }

    public void setOfflineClassCount(Long offlineClassCount) {
        this.offlineClassCount = offlineClassCount;
    }


    @Column(name = "class_count")
    public Long getClassCount() {
        return classCount;
    }


    public void setClassCount(Long classCount) {
        this.classCount = classCount;
    }

    @Column(name = "online_user_count")
    public Long getOnlineUserCount() {
        return onlineUserCount;
    }

    public void setOnlineUserCount(Long onlineUserCount) {
        this.onlineUserCount = onlineUserCount;
    }

    @Column(name = "offline_user_count")
    public Long getOfflineUserCount() {
        return offlineUserCount;
    }

    public void setOfflineUserCount(Long offlineUserCount) {
        this.offlineUserCount = offlineUserCount;
    }

    @Column(name = "core_user_count")
    public Long getCoreUserCount() {
        return coreUserCount;
    }

    public void setCoreUserCount(Long coreUserCount) {
        this.coreUserCount = coreUserCount;
    }

    @Column(name = "create_by")
    public Long getCreateBy() {
        return createBy;
    }


    public void setCreateBy(Long createBy) {
        this.createBy = createBy;
    }

    @Column(name = "update_by")
    public Long getUpdateBy() {
        return updateBy;
    }


    public void setUpdateBy(Long updateBy) {
        this.updateBy = updateBy;
    }

    @Column(name = "update_at")
    public Long getUpdateAt() {
        return updateAt;
    }


    public void setUpdateAt(Long updateAt) {
        this.updateAt = updateAt;
    }

    @Column(name = "create_at")
    public Long getCreateAt() {
        return createAt;
    }


    public void setCreateAt(Long createAt) {
        this.createAt = createAt;
    }

    public String toString() {
        return ToStringBuilder.reflectionToString(this,
                ToStringStyle.MULTI_LINE_STYLE);
    }

}

==> skill-core-25.0.5-sources.jar: com/ptteng/common/skill/model/Occupation.java <==
package com.ptteng.common.skill.model;

import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import javax.persistence.*;
import java.io.Serializable;


@Entity
@Table(name = "occupation")
public class Occupation implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 4962248169743004672L;
    /**
     *  未发布
     *
     */
    public static final Integer Status_Unpublished = 1;

    /**
     * 发布
     */
    public static final Integer Status_Published = 2;//强制更新
    /**
     * 在常量表中标记职业的Type
     */
	public static final String Constant_Type_occupation = "occupation_type";
    /**
     * js职业name,用于线下学员设置入学和结业时间时的排除选项
     * 线下学员入学时间为加入除js（web学员一般是先加css班级）班级时间，并根据班级所属分院，自动设置结业时间
     */

    public static final String Occupation_name_js = "js";

    public static final Long CSS_ID = 1L;
    public static final Long JS_ID = 2L;


    private Long id;


    private String name;


    private String CnName;

    //职业qq群，新增班级前端默认传职业qq群
    private String qq;

    //职业qqUrl，用于职业任务详情中加入qq群
    private String qqUrl;


    private String brief;


    private String description;


    private Integer threshold;


    private Integer difficult;


    private String cycle;
    
    private String basis;


    private Integer company;

    private String skillImg;


    private String img;


    private Long onlineGradeCount=0L;


    private Long offlineGradeCount=0L;


    private Long classCount=0L;


    private Long onlineClassCount=0L;


    private Long offlineClassCount=0L;


    private Long onlineUserCount=0L;
    private Long outlineUserCount=0L;

    private Long offlineUserCount=0L;


    private Long coreUserCount=0L;
    
    
   
    private Integer people;
    
    /**
     * 职业分组，跟Constant表里的name对应一致
     *
     */
    private String type;
    
    private String salary;


    /**
     * 职业模块
     */

    private String modules;

    /**
     * 职业问答模块
     */

    private String questionModules;

    private Long publishAt;
    
    private Integer status;
    
    private Long createBy;


    private Long updateBy;


    private Long updateAt;


    private Long createAt;
  
    

    
    
    /**
     * 修真院13期新增字段
     * @return
     */
    private String passingRate;
    private String completeTotal;
    private String completeTotalOffline;
    private String completeTotalOutline;
    private String completeTotalOnline;
    private String submitTaskTotal;
    private String submitTaskOffline;
    private String submitTaskOutline;
    private String submitTaskOnline;
    private String receiveTaskTotal;
    private String receiveTaskOffline;
    private String receiveTaskOutline;
    private String receiveTaskOnline;
    private String averageTimeTotal;
    private String averageTimeOffline;
    private String averageTimeOutline;
    private String averageTimeOnline;
    private String dailyQualityTotal;
    private String dailyQualityOffline;
    private String dailyQualityOutline;
    private String dailyQualityOnline;
    
    
    
    
    
    
    
    
    
    
    
    
    
    @Column(name="passing_rate")
    public String getPassingRate() {
		return passingRate;
	}


	public void setPassingRate(String passingRate) {
		this.passingRate = passingRate;
	}

	@Column(name="complete_total")
	public String getCompleteTotal() {
		return completeTotal;
	}


	public void setCompleteTotal(String completeTotal) {
		this.completeTotal = completeTotal;
	}

	@Column(name="complete_total_offline")
	public String getCompleteTotalOffline() {
		return completeTotalOffline;
	}


	public void setCompleteTotalOffline(String completeTotalOffline) {
		this.completeTotalOffline = completeTotalOffline;
	}

	@Column(name="complete_total_outline")
	public String getCompleteTotalOutline() {
		return completeTotalOutline;
	}


	public void setCompleteTotalOutline(String completeTotalOutline) {
		this.completeTotalOutline = completeTotalOutline;
	}

	@Column(name="complete_total_online")
	public String getCompleteTotalOnline() {
		return completeTotalOnline;
	}


	public void setCompleteTotalOnline(String completeTotalOnline) {
		this.completeTotalOnline = completeTotalOnline;
	}

	@Column(name="submit_task_total")
	public String getSubmitTaskTotal() {
		return submitTaskTotal;
	}


	public void setSubmitTaskTotal(String submitTaskTotal) {
		this.submitTaskTotal = submitTaskTotal;
	}

	@Column(name="submit_task_offline")
	public String getSubmitTaskOffline() {
		return submitTaskOffline;
	}


	public void setSubmitTaskOffline(String submitTaskOffline) {
		this.submitTaskOffline = submitTaskOffline;
	}

	@Column(name="submit_task_outline")
	public String getSubmitTaskOutline() {
		return submitTaskOutline;
	}


	public void setSubmitTaskOutline(String submitTaskOutline) {
		this.submitTaskOutline = submitTaskOutline;
	}

	@Column(name="submit_task_online")
	public String getSubmitTaskOnline() {
		return submitTaskOnline;
	}


	public void setSubmitTaskOnline(String submitTaskOnline) {
		this.submitTaskOnline = submitTaskOnline;
	}

	@Column(name="receive_task_total")
	public String getReceiveTaskTotal() {
		return receiveTaskTotal;
	}


	public void setReceiveTaskTotal(String receiveTaskTotal) {
		this.receiveTaskTotal = receiveTaskTotal;
	}

	@Column(name="receive_task_offline")
	public String getReceiveTaskOffline() {
		return receiveTaskOffline;
	}


	public void setReceiveTaskOffline(String receiveTaskOffline) {
		this.receiveTaskOffline = receiveTaskOffline;
	}

	@Column(name="receive_task_outline")
	public String getReceiveTaskOutline() {
		return receiveTaskOutline;
	}


	public void setReceiveTaskOutline(String receiveTaskOutline) {
		this.receiveTaskOutline = receiveTaskOutline;
	}

	@Column(name="receive_task_online")
	public String getReceiveTaskOnline() {
		return receiveTaskOnline;
	}


	public void setReceiveTaskOnline(String receiveTaskOnline) {
		this.receiveTaskOnline = receiveTaskOnline;
	}
  
	@Column(name="average_time_total")
	public String getAverageTimeTotal() {
		return averageTimeTotal;
	}


	public void setAverageTimeTotal(String averageTimeTotal) {
		this.averageTimeTotal = averageTimeTotal;
	}

	@Column(name="average_time_offline")
	public String getAverageTimeOffline() {
		return averageTimeOffline;
	}


	public void setAverageTimeOffline(String averageTimeOffline) {
		this.averageTimeOffline = averageTimeOffline;
	}

	@Column(name="average_time_outline")
	public String getAverageTimeOutline() {
		return averageTimeOutline;
	}


	public void setAverageTimeOutline(String averageTimeOutline) {
		this.averageTimeOutline = averageTimeOutline;
	}

	@Column(name="average_time_online")
	public String getAverageTimeOnline() {
		return averageTimeOnline;
	}


	public void setAverageTimeOnline(String averageTimeOnline) {
		this.averageTimeOnline = averageTimeOnline;
	}

	@Column(name="daily_quality_total")
	public String getDailyQualityTotal() {
		return dailyQualityTotal;
	}

    
	public void setDailyQualityTotal(String dailyQualityTotal) {
		this.dailyQualityTotal = dailyQualityTotal;
	}

	@Column(name="daily_quality_offline")
	public String getDailyQualityOffline() {
		return dailyQualityOffline;
	}


	public void setDailyQualityOffline(String dailyQualityOffline) {
		this.dailyQualityOffline = dailyQualityOffline;
	}

	@Column(name="daily_quality_outline")
	public String getDailyQualityOutline() {
		return dailyQualityOutline;
	}


	public void setDailyQualityOutline(String dailyQualityOutline) {
		this.dailyQualityOutline = dailyQualityOutline;
	}

	@Column(name="daily_quality_online")
	public String getDailyQualityOnline() {
		return dailyQualityOnline;
	}


	public void setDailyQualityOnline(String dailyQualityOnline) {
		this.dailyQualityOnline = dailyQualityOnline;
	}


	@Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "id")
    public Long getId() {
        return id;
    }


    public void setId(Long id) {
        this.id = id;
    }
    @Column(name = "outline_user_count")
    public Long getOutlineUserCount() {
        return outlineUserCount;
    }

    public void setOutlineUserCount(Long outlineUserCount) {
        this.outlineUserCount = outlineUserCount;
    }



    @Column(name = "modules")
    public String getModules() {
        return modules;
    }

    public void setModules(String modules) {
        this.modules = modules;
    }

    @Column(name = "question_modules")
    public String getQuestionModules() {
        return questionModules;
    }

    public void setQuestionModules(String questionModules) {
        this.questionModules = questionModules;
    }



    @Column(name = "publish_at")
    public Long getPublishAt() {
        return publishAt;
    }

    public void setPublishAt(Long publishAt) {
        this.publishAt = publishAt;
    }
    @Column(name = "status")
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
    @Column(name = "people")
    public Integer getPeople() {
        return people;
    }

    public void setPeople(Integer people) {
        this.people = people;
    }
    @Column(name = "salary")
    public String getSalary() {
        return salary;
    }

    public void setSalary(String salary) {
        this.salary = salary;
    }

    @Column(name = "name")
    public String getName() {
        return name;
    }


    public void setName(String name) {
        this.name = name;
    }

    @Column(name = "cn_name")
    public String getCnName() {
        return CnName;
    }

    public void setCnName(String cnName) {
        CnName = cnName;
    }


    @Column(name = "qq")
    public String getQq() {
        return qq;
    }

    public void setQq(String qq) {
        this.qq = qq;
    }

    @Column(name = "qq_url")
    public String getQqUrl() {
        return qqUrl;
    }

    public void setQqUrl(String qqUrl) {
        this.qqUrl = qqUrl;
    }

    @Column(name = "brief")
    public String getBrief() {
        return brief;
    }

    public void setBrief(String brief) {
        this.brief = brief;
    }
    
    
    
    @Column(name = "basis")
    public String getBasis() {
		return basis;
	}


	public void setBasis(String basis) {
		this.basis = basis;
	}


	@Column(name = "description")
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    @Column(name = "threshold")
    public Integer getThreshold() {
        return threshold;
    }

    public void setThreshold(Integer threshold) {
        this.threshold = threshold;
    }

    @Column(name = "difficult")
    public Integer getDifficult() {
        return difficult;
    }

    public void setDifficult(Integer difficult) {
        this.difficult = difficult;
    }

    @Column(name = "cycle")
    public String getCycle() {
        return cycle;
    }

    public void setCycle(String cycle) {
        this.cycle = cycle;
    }

    @Column(name = "company")
    public Integer getCompany() {
        return company;
    }

    public void setCompany(Integer company) {
        this.company = company;
    }

 
    @Column(name = "skill_img")
    public String getSkillImg() {
        return skillImg;
    }

    public void setSkillImg(String skillImg) {
        this.skillImg = skillImg;
    }


    @Column(name = "img")
    public String getImg() {
        return img;
    }

    public void setImg(String img) {
        this.img = img;
    }
    
    
    
    
    @Column(name = "type")
    public String getType() {
		return type;
	}


	public void setType(String type) {
		this.type = type;
	}


	@Column(name = "online_grade_count")
    public Long getOnlineGradeCount() {
        return onlineGradeCount;
    }

    public void setOnlineGradeCount(Long onlineGradeCount) {
        this.onlineGradeCount = onlineGradeCount;
    }

    @Column(name = "offline_grade_count")
    public Long getOfflineGradeCount() {
        return offlineGradeCount;
    }

    public void setOfflineGradeCount(Long offlineGradeCount) {
        this.offlineGradeCount = offlineGradeCount;
    }

    @Column(name = "online_class_count")
    public Long getOnlineClassCount() {
        return onlineClassCount;
    }

    public void setOnlineClassCount(Long onlineClassCount) {
        this.onlineClassCount = onlineClassCount;
    }

    @Column(name = "offline_class_count")
    public Long getOfflineClassCount() {
        return offlineClassCount;
    }

    public void setOfflineClassCount(Long offlineClassCount) {
        this.offlineClassCount = offlineClassCount;
    }


    @Column(name = "class_count")
    public Long getClassCount() {
        return classCount;
    }


    public void setClassCount(Long classCount) {
        this.classCount = classCount;
    }

    @Column(name = "online_user_count")
    public Long getOnlineUserCount() {
        return onlineUserCount;
    }

    public void setOnlineUserCount(Long onlineUserCount) {
        this.onlineUserCount = onlineUserCount;
    }

    @Column(name = "offline_user_count")
    public Long getOfflineUserCount() {
        return offlineUserCount;
    }

    public void setOfflineUserCount(Long offlineUserCount) {
        this.offlineUserCount = offlineUserCount;
    }

    @Column(name = "core_user_count")
    public Long getCoreUserCount() {
        return coreUserCount;
    }

    public void setCoreUserCount(Long coreUserCount) {
        this.coreUserCount = coreUserCount;
    }

    @Column(name = "create_by")
    public Long getCreateBy() {
        return createBy;
    }


    public void setCreateBy(Long createBy) {
        this.createBy = createBy;
    }

    @Column(name = "update_by")
    public Long getUpdateBy() {
        return updateBy;
    }


    public void setUpdateBy(Long updateBy) {
        this.updateBy = updateBy;
    }

    @Column(name = "update_at")
    public Long getUpdateAt() {
        return updateAt;
    }


    public void setUpdateAt(Long updateAt) {
        this.updateAt = updateAt;
    }

    @Column(name = "create_at")
    public Long getCreateAt() {
        return createAt;
    }


    public void setCreateAt(Long createAt) {
        this.createAt = createAt;
    }

    public String toString() {
        return ToStringBuilder.reflectionToString(this,
                ToStringStyle.MULTI_LINE_STYLE);
    }

}
